Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## tabler-icons.io

- Up
- Checked every 3 minutes

Configure
Pause this monitor
Currently up for
14 days 2 hours 54 mins 34 seconds
Last checked at
27 seconds ago
Incidents
3

### Response times across regions in the last day

### Uptime incidents per day

Time period | Availability | Downtime | Incidents | Longest incident | Avg. incident
--- | --- | --- | --- | --- | ---
Today | 98.9533% | 1 minute | 1 | 1 minute | 1 minute
Last 7 days | 98.9533% | 1 minute | 1 | 1 minute | 1 minute
Last 30 days | 98.9533% | 1 minute | 1 | 1 minute | 1 minute
Last 365 days | 98.9533% | 1 minute | 1 | 1 minute | 1 minute
All time | 98.9533% | 1 minute | 1 | 1 minute | 1 minute